@@ -51,8 +51,10 @@ def process_project(list_input_files, parameters):
     
     EE = ext_Experiment(sample_registry, parameters)
     EE.process_all()
-    EE.export_all()
+    EE.export_all(anno=parameters["anno"])
 
+    if not parameters['pickle'] and parameters['database_mode'] != 'memory':
+        remove_intermediate_pickles(parameters)
 
 def read_project_dir(directory, file_pattern='.mzML'):
     '''
@@ -73,11 +75,24 @@ def register_samples(list_input_files):
     return sample_registry
 
 def create_export_folders(parameters, time_stamp):
-    parameters['outdir'] = '_'.join([parameters['project_name'], parameters['outdir'], time_stamp]) 
+    parameters['outdir'] = '_'.join([parameters['outdir'], parameters['project_name'], time_stamp]) 
+    parameters['tmp_pickle_dir'] = os.path.join(parameters['outdir'], 'pickle')
     os.mkdir(parameters['outdir'])
-    os.mkdir(os.path.join(parameters['outdir'], 'pickle'))
+    os.mkdir(parameters['tmp_pickle_dir'])
     os.mkdir(os.path.join(parameters['outdir'], 'export'))
 
+def remove_intermediate_pickles(parameters):
+    '''
+    Remove all temporary files under pickle/ to free up disk space. 
+    '''
+    print("Removing temporary pickle files...")
+    for f in os.listdir(parameters['tmp_pickle_dir']):
+        os.remove( os.path.join(parameters['tmp_pickle_dir'], f) )
+    try:
+        os.rmdir(parameters['tmp_pickle_dir'])
+    except:
+        print("Failed to remove directory %s." %parameters['tmp_pickle_dir'])
+
 
 # -----------------------------------------------------------------------------
 # Mass track (EIC) extraction, multi-core parralization via multiprocessing
